/************************************************************************************
Replication data and analyses for:
Thyne, Clayton L., Jonathan Powell, Sarah Parrott, and Emily Vanmeter. 2017. 
'Even Generals Need Friends: How Domestic and International Relations to Coups
Influence Regime Survival.' Journal of Conflict Resolution, forthcoming.
************************************************************************************/

/*PRIMARY ANALYSES*/

use "thyne_et_al_JCRreps.dta", clear
/*T1M1*/	streg domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T1M2*/ 	streg domestic_protests intl_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T1M3*/ 	streg domestic_protests intl_protests intl_protestsSD inter gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T1M4*/	streg domestic_protests intl_protests inter2 gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T2M1*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T2M2*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year<1989, d(w) nolog time cluster(ccode)
/*T2M3*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year>=1989, d(w) nolog time cluster(ccode)
/*T2M4*/	streg intl_protests_ios intl_protests_majpows intl_protests_nonmajpows domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T2M5*/	streg intl_protests_ios intl_protests_trader intl_protests_nontrader domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*T2M6*/	streg intl_protests_ios intl_protests_allies intl_protests_nonallies domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)

/*APPENDIX ANALYSES*/

/*Appendix, Table 1*/
use "thyne_et_al_JCRreps.dta", clear
sum _t domestic_protests intl_protests gdppc chgdp pop recent_failed_coup prev_gdppc prev_chgdp prev_prot prev_san prev_dem

/*Appendix, Figure 1*/
use "thyne_et_al_JCRreps_App_Fig_1.dta", clear
hist time_difference, percent xtitle("Days") title("App. Figure 1. Time between Coup Date and Signal Date") scheme(s1mono)

/*Appendix, Figure 2a*/
use "thyne_et_al_JCRreps_App_Fig_2a.dta", clear
hist intl_protests, frequency xtitle("") ytitle("Statement frequency") scheme(s1mono) title(" App. Figure 2a. Frequency of Post-coup Signals, 1950-2013") ///
	text(375 5 "Hostile reactions") text(375 -5 "Supportive reactions")

/*Appendix, Figure 2b*/
use "thyne_et_al_JCRreps_App_Fig_2b.dta", clear
twoway 	(line pos year, lc(black) lpat(solid)) ///
		(line neg year, lc(black) lpat(dash)), ///
		scheme(s1mono) xlabel(1950(10)2010) ylabel(0(20)80) xtitle("") ytitle("Statement frequency") title("App Figure 2b. Frequency of Post-coup Signals, 1950-2013")

/*Appendix, Table 2*/
use "thyne_et_al_JCRreps_App_Table2.dta", clear
/*AppT2M1*/ streg domestic_protests intl_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT2M2*/ streg domestic_protests_LN intl_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT2M3*/ streg domestic_protests_dum intl_protests_dum intl_support_dum mixed_intl_dum gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)

/*Appendix, Table 3a*/
use "thyne_et_al_JCRreps.dta", clear
/*AppT3aM1*/	streg domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3aM2*/ 	streg domestic_protests intl_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3aM3*/ 	streg domestic_protests intl_protests intl_protestsSD inter gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3aM4*/	streg domestic_protests intl_protests inter2 gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared

/*Appendix, Table 3b*/
use "thyne_et_al_JCRreps.dta", clear
/*AppT3bM1*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3bM2*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year<1989, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3bM3*/	streg intl_protests_ios intl_protests_states domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year>=1989, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3bM4*/	streg intl_protests_ios intl_protests_majpows intl_protests_nonmajpows domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3bM5*/	streg intl_protests_ios intl_protests_trader intl_protests_nontrader domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared
/*AppT3bM6*/	streg intl_protests_ios intl_protests_allies intl_protests_nonallies domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time frailty(gamma) shared(ccode) forceshared

/*Appendix, Table 4a*/
use "thyne_et_al_JCRreps_App_Table4.dta", clear	
/*AppT4aM1*/ dursel time domestic_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4aM2*/ dursel time domestic_protests intl_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4aM3*/ dursel time domestic_protests intl_protests intl_protestsSD inter gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4aM4*/ dursel time domestic_protests intl_protests inter2 gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time

/*Appendix, Table 4b*/
use "thyne_et_al_JCRreps_App_Table4.dta", clear		
/*AppT4bM5*/ dursel time intl_protests_states intl_protests_ios domestic_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4bM6*/ dursel time intl_protests_states intl_protests_ios domestic_protests gdppc chgdppc pop recent_failed_coup if year<1989, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4bM7*/ dursel time intl_protests_states intl_protests_ios domestic_protests gdppc chgdppc pop recent_failed_coup if year>=1989, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4bM8*/ dursel time intl_protests_majpows intl_protests_nonmajpows sig_ios domestic_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4bM9*/ dursel time intl_protests_trader intl_protests_nontrader intl_protests_ios domestic_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time
/*AppT4bM10*/ dursel time intl_protests_allies intl_protests_nonallies intl_protests_ios domestic_protests gdppc chgdppc pop recent_failed_coup, ///
	sel(coup = protests sanctions gdppc chgdppc polity coup_time coup_time2 coup_time3) d(weibull) difficult time

/*Appendix, Table 5a*/
use "thyne_et_al_JCRreps_App_Table5.dta", clear	
/*AppT5aM1*/			 	streg domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5aM2*/ 		streg intl_protests domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5aM3*/ 		streg intl_protests intl_protestsSD inter domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5aM4*/				streg intl_protests inter2 domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)

/*Appendix, Table 5b*/
use "thyne_et_al_JCRreps_App_Table5.dta", clear	
/*AppT5bM5*/		streg intl_protests_states intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5bM6*/		streg intl_protests_states intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year<1989, d(w) nolog time cluster(ccode)
/*AppT5bM7*/		streg intl_protests_states intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem if year>=1989, d(w) nolog time cluster(ccode)
/*AppT5bM8*/		streg intl_protests_majpow intl_protests_nonmajpow intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5bM9*/		streg intl_protests_trader intl_protests_nontrader intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
/*AppT5bM10*/		streg intl_protests_allies intl_protests_nonallies intl_protests_ios domestic_protests gdppc chgdp pop recent_failed_coup prev_prot prev_san prev_gdppc prev_chgdppc prev_dem, d(w) nolog time cluster(ccode)
